;+
;
; ===================
; file_prn_to_mem.pro
; ===================
;
; .. function:: file_prn_to_mem()
;
;    Read all station information files and store data in a structure
;
; nb : mld float to handle NaN in file
;
;    :returns: data structure +todo+ details or -1 if error
;    :rtype: structure +todo+ details
;
; :examples:
;
; Realistic example with POMME files:
;
; .. code-block:: idl
;
;    result = file_prn_to_mem()
;
; impression de controle:
;
; .. code-block:: idl
;
;    help, result, /structure
;    print, result
;
; :uses:
;
; :func:`file_prn2mem`
;
; :see also:
;
; :program:`fig_mld`
;
; :todo:
;
; parametrisation ??
;
; learn how to concatenate array of structure (and avoid loop)
;
; réparer lien sphinx à fig_mld
;
; :history:
;
; - fplod 20101126T134144Z aedon.locean-ipsl.upmc.fr (Darwin)
;
;   * creation
;
; :version:
;
; $Id$
;
;-
FUNCTION file_prn_to_mem
    ;
    ; Return to caller if errors
    ON_ERROR, 2
    ;
    usage = 'result = file_prn_to_mem()'
    nparam = N_PARAMS()
    IF (nparam NE 0) THEN BEGIN
        ras = report(['Incorrect number of arguments.' $
        + '!C' $
        + 'Usage : ' + usage])
        return, -1
    ENDIF
    ;
    resultstruct = { station: 0L $
    , doy: 0.0 $
    , zhom001: 0.0 $
    , zhom002 : 0.0 $
    , zhom005 : 0.0 $
    , zhom010: 0.0 $
    , zhomelch : 0.0 $
    }
    ;
    nrows = 0L
    ;
    filename='/usr/work/incas/fplod/pomme_d/mld_prieur_P1L1.prn'
    data_p1l1 = file_prn2mem(filename)
    nrows = nrows + n_elements(data_p1l1)
    filename='/usr/work/incas/fplod/pomme_d/mld_prieur_P1L2_tot.prn'
    data_p1l2 = file_prn2mem(filename)
    nrows = nrows + n_elements(data_p1l2)
    filename='/usr/work/incas/fplod/pomme_d/mld_prieur_P2L1.prn'
    data_p2l1 = file_prn2mem(filename)
    nrows = nrows + n_elements(data_p2l1)
    filename='/usr/work/incas/fplod/pomme_d/mld_prieur_P2L2.prn'
    data_p2l2 = file_prn2mem(filename)
    nrows = nrows + n_elements(data_p2l2)
    ;
    result = Replicate(resultstruct, nrows)
    ;
    offset = 0L
    ;
    nstations = n_elements(data_p1l1)
    FOR istation = 0L, nstations - 1 DO BEGIN
        rstation = istation + offset
        result[rstation].station = data_p1l1[istation].station
        result[rstation].doy = data_p1l1[istation].doy
        result[rstation].zhom001 = data_p1l1[istation].zhom001
        result[rstation].zhom002 = data_p1l1[istation].zhom002
        result[rstation].zhom005 = data_p1l1[istation].zhom005
        result[rstation].zhom010 = data_p1l1[istation].zhom010
        result[rstation].zhomelch = data_p1l1[istation].zhomelch
    ENDFOR

    offset = offset + nstations
    ;
    nstations = n_elements(data_p1l2)
    FOR istation = 0L, nstations - 1 DO BEGIN
        rstation = istation + offset
        result[rstation].station = data_p1l2[istation].station
        result[rstation].doy = data_p1l2[istation].doy
        result[rstation].zhom001 = data_p1l2[istation].zhom001
        result[rstation].zhom002 = data_p1l2[istation].zhom002
        result[rstation].zhom005 = data_p1l2[istation].zhom005
        result[rstation].zhom010 = data_p1l2[istation].zhom010
        result[rstation].zhomelch = data_p1l2[istation].zhomelch
    ENDFOR

    offset = offset + nstations
    ;
    nstations = n_elements(data_p2l1)
    ;
    FOR istation = 0L, nstations - 1 DO BEGIN
        rstation = istation + offset
        result[rstation].station = data_p2l1[istation].station
        result[rstation].doy = data_p2l1[istation].doy
        result[rstation].zhom001 = data_p2l1[istation].zhom001
        result[rstation].zhom002 = data_p2l1[istation].zhom002
        result[rstation].zhom005 = data_p2l1[istation].zhom005
        result[rstation].zhom010 = data_p2l1[istation].zhom010
        result[rstation].zhomelch = data_p2l1[istation].zhomelch
    ENDFOR

    offset = offset + nstations
    ;
    nstations = n_elements(data_p2l2)
    FOR istation = 0L, nstations - 1 DO BEGIN
        rstation = istation + offset
        result[rstation].station = data_p2l2[istation].station
        result[rstation].doy = data_p2l2[istation].doy
        result[rstation].zhom001 = data_p2l2[istation].zhom001
        result[rstation].zhom002 = data_p2l2[istation].zhom002
        result[rstation].zhom005 = data_p2l2[istation].zhom005
        result[rstation].zhom010 = data_p2l2[istation].zhom010
        result[rstation].zhomelch = data_p2l2[istation].zhomelch
    ENDFOR
    ;
    return, result

END
